@@ -34,7 +34,14 @@ Exit code used when there was an unhandled exception.
 """
 UNKNOWN_ERROR = 105
 
-""" Malformed Heartbeat Error
-Exit code used when the JSON input from `--extra-heartbeats` is malformed.
+""" Connection Error
+Exit code used when there was proxy or other problem connecting to the WakaTime
+API servers.
 """
-MALFORMED_HEARTBEAT_ERROR = 106
+CONNECTION_ERROR = 107
+
+""" Max file size supporting line number count stats.
+Files larger than this in bytes will not have a line count stat for performance.
+Default is 2MB.
+"""
+MAX_FILE_SIZE_SUPPORTED = 2000000
